@@ -221,7 +221,8 @@ class Geometry:
     @supress_logging
     @run_as_prep7
     def generate_surface(self, density=4, amin=None, amax=None, ninc=None):
-        """Generate an all-triangular surface of the active surfaces.
+        """
+        Generate an all-triangular surface of the active surfaces.
 
         Parameters
         ----------
@@ -325,7 +326,8 @@ class Geometry:
 
     @property
     def n_volu(self):
-        """Number of volumes currently selected
+        """
+        Number of volumes currently selected.
 
         Examples
         --------
@@ -336,7 +338,8 @@ class Geometry:
 
     @property
     def n_area(self):
-        """Number of areas currently selected
+        """
+        Number of areas currently selected.
 
         Examples
         --------
@@ -347,7 +350,8 @@ class Geometry:
 
     @property
     def n_line(self):
-        """Number of lines currently selected
+        """
+        Number of lines currently selected.
 
         Examples
         --------
@@ -358,7 +362,8 @@ class Geometry:
 
     @property
     def n_keypoint(self):
-        """Number of keypoints currently selected
+        """
+        Number of keypoints currently selected.
 
         Examples
         --------
@@ -369,12 +374,13 @@ class Geometry:
 
     @supress_logging
     def _item_count(self, entity):
-        """Return item count for a given entity"""
+        """Return item count for a given entity."""
         return int(self._mapdl.get(entity=entity, item1="COUNT"))
 
     @property
     def knum(self):
-        """Array of keypoint numbers.
+        """
+        Array of keypoint numbers.
 
         Examples
         --------
